@@ -5,7 +5,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  *   copyright (C) 2004-2013                                               *
- *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
+ *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
 // own header
@@ -14,6 +14,7 @@
 // app includes
 #include "assocrules.h"
 #include "association.h"
+#include "associationline.h"
 #include "associationwidget.h"
 #include "classifierwidget.h"
 #include "debug_utils.h"
@@ -80,7 +81,7 @@ void ToolBarStateAssociation::mouseMove(QGraphicsSceneMouseEvent* ome)
     ToolBarStatePool::mouseMove(ome);
 
     if (m_associationLine) {
-        UMLScenePoint sp = m_associationLine->line().p1();
+        QPointF sp = m_associationLine->line().p1();
         m_associationLine->setLine(sp.x(), sp.y(), m_pMouseEvent->scenePos().x(), m_pMouseEvent->scenePos().y());
     }
 }
@@ -118,7 +119,7 @@ void ToolBarStateAssociation::mouseReleaseAssociation()
     currentAssociation()->createAssocClassLine(
             static_cast<ClassifierWidget*>(m_firstWidget),
             currentAssociation()->associationLine()->closestSegmentIndex(m_pMouseEvent->scenePos()));
-    m_firstWidget->addAssoc( currentAssociation() );
+    m_firstWidget->addAssoc(currentAssociation());
     cleanAssociation();
 }
 
