@@ -4,8 +4,8 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2006-2011                                               *
- *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
+ *   copyright (C) 2006-2013                                               *
+ *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
 #ifndef UMLVIEWIMAGEEXPORTERMODEL_H
@@ -57,7 +57,7 @@ private:
     bool exportViewToSvg(UMLScene* scene, const QString &fileName) const;
     bool exportViewToPixmap(UMLScene* scene, const QString &imageType, const QString &fileName) const;
 
-    bool fixEPS(const QString &fileName, const UMLSceneRect& rect) const;
+    bool fixEPS(const QString &fileName, const QRectF& rect) const;
 
     static QStringList s_supportedImageTypesList;
     static QStringList s_supportedMimeTypesList;
