@@ -5,7 +5,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  *   copyright (C) 2002-2013                                               *
- *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
+ *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
 #ifndef MESSAGEWIDGET_H
@@ -20,7 +20,6 @@ class ObjectWidget;
 class QMoveEvent;
 class QResizeEvent;
 class UMLOperation;
-class MessageWidgetController;
 
 /**
  * Used to display a message on a sequence diagram.  The message
@@ -37,14 +36,12 @@ class MessageWidgetController;
  * @see UMLWidget
  * @see ObjectWidget
  * @see FloatingTextWidget
- * Bugs and comments to uml-devel@lists.sf.net or http://bugs.kde.org
+ * Bugs and comments to umbrello-devel@kde.org or http://bugs.kde.org
  */
 class MessageWidget : public UMLWidget, public LinkWidget
 {
     Q_OBJECT
 public:
-    friend class MessageWidgetController;
-
     MessageWidget(UMLScene * scene, ObjectWidget* a, ObjectWidget* b,
                   int y, Uml::SequenceMessage::Enum sequenceMessageType,
                   Uml::ID::Type id = Uml::ID::None);
@@ -55,7 +52,7 @@ public:
                   Uml::ID::Type id = Uml::ID::None);
     virtual ~MessageWidget();
 
-    virtual void setY(UMLSceneValue y);
+    virtual void setY(qreal y);
 
     //---------- LinkWidget Interface methods implemementation from now on.
 
@@ -74,7 +71,7 @@ public:
     virtual UMLClassifier* seqNumAndOp(QString& seqNum, QString& op);
     virtual void setSeqNumAndOp(const QString &seqNum, const QString &op);
 
-    virtual void constrainTextPos(UMLSceneValue &textX, UMLSceneValue &textY, UMLSceneValue textWidth, UMLSceneValue textHeight,
+    virtual void constrainTextPos(qreal &textX, qreal &textY, qreal textWidth, qreal textHeight,
                                   Uml::TextRole::Enum tr);
 
     //---------- End LinkWidget Interface methods implemementation.
@@ -134,7 +131,9 @@ public:
     int getMinY();
     int getMaxY();
 
-    UMLSceneValue onWidget(const UMLScenePoint & p);
+    qreal onWidget(const QPointF& p);
+
+    virtual void resizeWidget(qreal newW, qreal newH);
 
     virtual void saveToXMI(QDomDocument & qDoc, QDomElement & qElement);
     virtual bool loadFromXMI(QDomElement & qElement);
@@ -152,12 +151,17 @@ public:
 protected:
     virtual void mouseDoubleClickEvent(QGraphicsSceneMouseEvent *event);
 
+    virtual void moveWidgetBy(qreal diffX, qreal diffY);
+    virtual void constrainMovementForAllWidgets(qreal &diffX, qreal &diffY);
+
+    virtual QCursor resizeCursor() const;
+
     void setLinkAndTextPos();
 
     int constrainX(int textX, int textWidth, Uml::TextRole::Enum tr);
 
-    static void paintArrow( QPainter *p, int x, int y, int w,
-                           Qt::ArrowType direction, bool useDottedLine = false );
+    static void paintArrow(QPainter *p, int x, int y, int w,
+                           Qt::ArrowType direction, bool useDottedLine = false);
     static void paintSolidArrowhead(QPainter *p, int x, int y, Qt::ArrowType direction);
 
     void updateResizability();
@@ -180,6 +184,8 @@ private:
     void moveEvent(QGraphicsSceneMouseEvent *m);
     void resizeEvent(QResizeEvent *re);
 
+    qreal constrainPositionY(qreal diffY);
+
     void init();
 
     ObjectWidget * m_pOw[2];
@@ -196,6 +202,9 @@ private:
      */
     Uml::ID::Type m_widgetAId, m_widgetBId, m_textId;
 
+    /// The vertical position the widget would have if its move wasn't constrained.
+    qreal m_unconstrainedPositionY;
+
 public slots:
     void slotWidgetMoved(Uml::ID::Type id);
     void slotMenuSelection(QAction* action);
