@@ -5,7 +5,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  *   copyright (C) 2002-2013                                               *
- *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
+ *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
 // own header file
@@ -14,13 +14,14 @@
 // local includes
 #include "classpropdlg.h"
 #include "debug_utils.h"
+#include "docwindow.h"
 #include "listpopupmenu.h"
 #include "messagewidget.h"
-#include "objectwidgetcontroller.h"
 #include "seqlinewidget.h"
 #include "uml.h"
 #include "umldoc.h"
 #include "umlobject.h"
+#include "umlscene.h"
 #include "umlview.h"
 
 // kde includes
@@ -38,6 +39,8 @@
 #define A_HEIGHT 40
 #define A_MARGIN 5
 
+DEBUG_REGISTER_DISABLED(ObjectWidget)
+
 /**
  * The number of pixels margin between the lowest message
  * and the bottom of the vertical line
@@ -55,19 +58,19 @@ ObjectWidget::ObjectWidget(UMLScene * scene, UMLObject *o, Uml::ID::Type lid)
   : UMLWidget(scene, WidgetBase::wt_Object, o),
     m_multipleInstance(false),
     m_drawAsActor(false),
-    m_showDestruction(false)
+    m_showDestruction(false),
+    m_isOnDestructionBox(false)
 {
     m_nLocalID = Uml::ID::None;
-    if( m_scene != NULL && m_scene->type() == Uml::DiagramType::Sequence ) {
+    if (m_scene && (m_scene->type() == Uml::DiagramType::Sequence)) {
         m_pLine = new SeqLineWidget( m_scene, this );
-        //Sets specific widget controller for sequence diagrams
-        delete m_widgetController;
-        m_widgetController = new ObjectWidgetController(this);
+        m_pLine->setStartPoint(x() + width() / 2, y() + height());
     } else {
         m_pLine = 0;
     }
-    if( lid != Uml::ID::None )
+    if (lid != Uml::ID::None) {
         m_nLocalID = lid;
+    }
 }
 
 /**
@@ -107,11 +110,11 @@ Uml::ID::Type ObjectWidget::localID() const
 void ObjectWidget::setMultipleInstance(bool multiple)
 {
     //make sure only calling this in relation to an object on a collab. diagram
-    if(m_scene->type() != Uml::DiagramType::Collaboration)
-        return;
-    m_multipleInstance = multiple;
-    updateGeometry();
-    update();
+    if (m_scene && (m_scene->type() == Uml::DiagramType::Collaboration)) {
+        m_multipleInstance = multiple;
+        updateGeometry();
+        update();
+    }
 }
 
 /**
@@ -124,6 +127,40 @@ bool ObjectWidget::multipleInstance() const
     return m_multipleInstance;
 }
 
+/**
+ * Overridden from UMLWidget.
+ * Moves the widget to a new position using the difference between the
+ * current position and the new position.
+ * Y position is ignored, and widget is only moved along X axis.
+ *
+ * @param diffX The difference between current X position and new X position.
+ * @param diffY The difference between current Y position and new Y position
+ *                          (isn't used).
+ */
+void ObjectWidget::moveWidgetBy(qreal diffX, qreal diffY)
+{
+    setX(x() + diffX);
+    if (m_scene && (m_scene->type() != Uml::DiagramType::Sequence)) {
+        setY(y() + diffY);
+    }
+}
+
+/**
+ * Overridden from UMLWidget.
+ * Modifies the value of the diffX and diffY variables used to move the widgets.
+ * All the widgets are constrained to be moved only in X axis (diffY is set to 0).
+ *
+ * @param diffX The difference between current X position and new X position.
+ * @param diffY The difference between current Y position and new Y position.
+ */
+void ObjectWidget::constrainMovementForAllWidgets(qreal &diffX, qreal &diffY)
+{
+    Q_UNUSED(diffX);
+    if (m_scene && (m_scene->type() == Uml::DiagramType::Sequence)) {
+        diffY = 0;
+    }
+}
+
 /**
  * Override default method.
  */
@@ -132,7 +169,7 @@ void ObjectWidget::paint(QPainter *painter, const QStyleOptionGraphicsItem *opti
     Q_UNUSED(option);
     Q_UNUSED(widget);
 
-    if ( m_drawAsActor )
+    if (m_drawAsActor)
         paintActor(painter);
     else
         paintObject(painter);
@@ -163,7 +200,7 @@ void ObjectWidget::slotMenuSelection(QAction* action)
             if (ok) {
                 m_instanceName = name;
                 updateGeometry();
-                moveEvent( 0 );
+                moveEvent(0);
                 update();
                 UMLApp::app()->document()->setModified(true);
             }
@@ -173,7 +210,7 @@ void ObjectWidget::slotMenuSelection(QAction* action)
     case ListPopupMenu::mt_Properties:
         showPropertiesDialog();
         updateGeometry();
-        moveEvent( 0 );
+        moveEvent(0);
         update();
         break;
 
@@ -194,14 +231,14 @@ void ObjectWidget::slotMenuSelection(QAction* action)
 /**
  * Overrides method from UMLWidget
  */
-UMLSceneSize ObjectWidget::minimumSize()
+QSizeF ObjectWidget::minimumSize()
 {
     int width, height;
     const QFontMetrics &fm = getFontMetrics(FT_UNDERLINE);
     const int fontHeight  = fm.lineSpacing();
     const QString t = m_instanceName + " : " + name();
     const int textWidth = fm.width(t);
-    if ( m_drawAsActor ) {
+    if (m_drawAsActor) {
         width = textWidth > A_WIDTH?textWidth:A_WIDTH;
         height = A_HEIGHT + fontHeight + A_MARGIN;
         width += A_MARGIN * 2;
@@ -215,7 +252,7 @@ UMLSceneSize ObjectWidget::minimumSize()
         }
     }//end else drawasactor
 
-    return UMLSceneSize(width, height);
+    return QSizeF(width, height);
 }
 
 /**
@@ -258,7 +295,7 @@ bool ObjectWidget::activate(IDChangeLog* ChangeLog /*= 0*/)
  *
  * @param x The x-coordinate to be set.
  */
-void ObjectWidget::setX(UMLSceneValue x)
+void ObjectWidget::setX(qreal x)
 {
     UMLWidget::setX(x);
     moveEvent(0);
@@ -270,7 +307,7 @@ void ObjectWidget::setX(UMLSceneValue x)
  *
  * @param y The y-coordinate to be set.
  */
-void ObjectWidget::setY(UMLSceneValue y)
+void ObjectWidget::setY(qreal y)
 {
     UMLWidget::setY(y);
     moveEvent(0);
@@ -280,7 +317,7 @@ void ObjectWidget::setY(UMLSceneValue y)
  * Return the x coordinate of the widgets center.
  * @return The x-coordinate of the widget center.
  */
-UMLSceneValue ObjectWidget::centerX()
+qreal ObjectWidget::centerX()
 {
     return x() + width()/2;
 }
@@ -288,25 +325,77 @@ UMLSceneValue ObjectWidget::centerX()
 /**
  * Overrides the standard operation.
  */
-void ObjectWidget::moveEvent(QGraphicsSceneMouseEvent *m)
+void ObjectWidget::moveEvent(QGraphicsSceneMouseEvent *event)
 {
-    Q_UNUSED(m)
-    emit sigWidgetMoved( m_nLocalID );
+    Q_UNUSED(event)
+    emit sigWidgetMoved(m_nLocalID);
     if (m_pLine) {
         m_pLine->setStartPoint(x() + width() / 2, y() + height());
     }
 }
 
+/**
+ * Overrides the standard operation.
+ */
+void ObjectWidget::mousePressEvent(QGraphicsSceneMouseEvent *me)
+{
+    UMLWidget::mousePressEvent(me);
+    m_isOnDestructionBox = false;
+    if (m_pLine && m_pLine->onDestructionBox(me->scenePos())) {
+        m_isOnDestructionBox = true;
+        qreal oldX = x() + width() / 2;
+        qreal oldY = getEndLineY() - 10;
+        m_oldPos = QPointF(oldX, oldY);
+    }
+}
+
+/**
+ * Overrides the standard operation.
+ */
+void ObjectWidget::mouseMoveEvent(QGraphicsSceneMouseEvent* me)
+{
+    if (m_inResizeArea) {
+        DEBUG(DBG_SRC) << "resizing...";
+        resize(me);
+        moveEvent(0);
+        return;
+    }
+
+    if (m_isOnDestructionBox) {
+        qreal diffY = me->scenePos().y() - m_oldPos.y();
+        moveDestructionBy(diffY);
+    }
+    else {
+        UMLWidget::mouseMoveEvent(me);
+    }
+}
+
+/**
+ * Moves the destruction Box to a new position using the difference between the
+ * current position and the new position.
+ * The destruction box is only moved along Y axis.
+ *
+ * @param diffY The difference between current Y position and new Y position
+ */
+void ObjectWidget::moveDestructionBy(qreal diffY)
+{
+    // endLine = length of the life line + diffY - 10 to center on the destruction box
+    qreal endLine = getEndLineY() + diffY - 10;
+    SeqLineWidget *pLine = sequentialLine();
+    pLine->setEndOfLine(endLine);
+    m_oldPos.setY(endLine);
+}
+
 /**
  * Handles a color change signal.
  */
 void ObjectWidget::slotFillColorChanged(Uml::ID::Type /*viewID*/)
 {
-    UMLWidget::setFillColor( m_scene->fillColor() );
-    UMLWidget::setLineColor( m_scene->lineColor() );
+    UMLWidget::setFillColor(m_scene->fillColor());
+    UMLWidget::setLineColor(m_scene->lineColor());
 
-    if( m_pLine)
-        m_pLine->setPen( QPen( UMLWidget::lineColor(), UMLWidget::lineWidth(), Qt::DashLine ) );
+    if(m_pLine)
+        m_pLine->setPen(QPen(UMLWidget::lineColor(), UMLWidget::lineWidth(), Qt::DashLine));
 }
 
 /**
@@ -315,7 +404,7 @@ void ObjectWidget::slotFillColorChanged(Uml::ID::Type /*viewID*/)
 void ObjectWidget::cleanup()
 {
     UMLWidget::cleanup();
-    if( m_pLine ) {
+    if(m_pLine) {
         m_pLine->cleanup();
         delete m_pLine;
     }
@@ -326,10 +415,10 @@ void ObjectWidget::cleanup()
  */
 void ObjectWidget::showPropertiesDialog()
 {
-    umlScene()->updateDocumentation(false);
+    UMLApp::app()->docWindow()->updateDocumentation(false);
     QPointer<ClassPropDlg> dlg = new ClassPropDlg((QWidget*)UMLApp::app(), this);
     if (dlg->exec()) {
-        umlScene()->showDocumentation(this, true);
+        UMLApp::app()->docWindow()->showDocumentation(this, true);
         UMLApp::app()->document()->setModified(true);
     }
     dlg->close();
@@ -343,8 +432,8 @@ void ObjectWidget::paintObject(QPainter *painter)
 {
     QFont oldFont = painter->font();
     QFont font = UMLWidget::font();
-    font.setUnderline( true );
-    painter->setFont( font );
+    font.setUnderline(true);
+    painter->setFont(font);
 
     setPenFromSettings(painter);
     if(UMLWidget::useFillColor())
@@ -356,7 +445,7 @@ void ObjectWidget::paintObject(QPainter *painter)
 
     const QString t = m_instanceName + " : " + name();
     int multiInstOfst = 0;
-    if ( m_multipleInstance ) {
+    if (m_multipleInstance) {
         painter->drawRect(10, 10, w - 10, h - 10);
         painter->drawRect(5, 5, w - 10, h - 10);
         multiInstOfst = 10;
@@ -367,7 +456,7 @@ void ObjectWidget::paintObject(QPainter *painter)
                w - O_MARGIN * 2 - multiInstOfst, h - O_MARGIN * 2 - multiInstOfst,
                Qt::AlignCenter, t);
 
-    painter->setFont( oldFont );
+    painter->setFont(oldFont);
 }
 
 /**
@@ -378,8 +467,8 @@ void ObjectWidget::paintActor(QPainter *painter)
     const QFontMetrics &fm = getFontMetrics(FT_UNDERLINE);
 
     setPenFromSettings(painter);
-    if ( UMLWidget::useFillColor() )
-        painter->setBrush( UMLWidget::fillColor() );
+    if (UMLWidget::useFillColor())
+        painter->setBrush(UMLWidget::fillColor());
     const int w = width();
     const int textStartY = A_HEIGHT + A_MARGIN;
     const int fontHeight  = fm.lineSpacing();
@@ -411,9 +500,9 @@ void ObjectWidget::tabUp()
     int newY = y() - height();
     if (newY < topMargin())
         newY = topMargin();
-    setY( newY );
-    moveEvent( 0 );
-    adjustAssocs( x(), newY);
+    setY(newY);
+    moveEvent(0);
+    adjustAssocs(x(), newY);
 }
 
 /**
@@ -422,9 +511,9 @@ void ObjectWidget::tabUp()
 void ObjectWidget::tabDown()
 {
     int newY = y() + height();
-    setY( newY );
-    moveEvent( 0 );
-    adjustAssocs( x(), newY);
+    setY(newY);
+    moveEvent(0);
+    adjustAssocs(x(), newY);
 }
 
 /**
@@ -456,7 +545,7 @@ bool ObjectWidget::canTabUp()
 void ObjectWidget::setShowDestruction(bool bShow)
 {
     m_showDestruction = bShow;
-    if( m_pLine )
+    if(m_pLine)
         m_pLine->setupDestructionBox();
 }
 
@@ -477,7 +566,9 @@ bool ObjectWidget::showDestruction() const
  */
 void ObjectWidget::setEndLine(int yPosition)
 {
-    m_pLine->setEndOfLine(yPosition);
+    if (m_pLine) {
+        m_pLine->setEndOfLine(yPosition);
+    }
 }
 
 /**
@@ -488,9 +579,9 @@ void ObjectWidget::setEndLine(int yPosition)
 int ObjectWidget::getEndLineY()
 {
     int y = this->y() + height();
-    if( m_pLine)
+    if(m_pLine)
         y += m_pLine->getLineLength();
-    if ( m_showDestruction )
+    if (m_showDestruction)
         y += 10;
     return y;
 }
@@ -502,7 +593,7 @@ int ObjectWidget::getEndLineY()
  */
 void ObjectWidget::messageAdded(MessageWidget* message)
 {
-    if ( m_messages.count(message) ) {
+    if (m_messages.count(message)) {
         uError() << message->name() << ": duplicate entry !";
         return ;
     }
@@ -516,7 +607,7 @@ void ObjectWidget::messageAdded(MessageWidget* message)
  */
 void ObjectWidget::messageRemoved(MessageWidget* message)
 {
-    if ( m_messages.removeAll(message) == false ) {
+    if (m_messages.removeAll(message) == false) {
         uError() << message->name() << ": missing entry !";
         return ;
     }
@@ -529,14 +620,16 @@ void ObjectWidget::messageRemoved(MessageWidget* message)
  */
 void ObjectWidget::slotMessageMoved()
 {
-    int lowestMessage = 0;
-    foreach (MessageWidget* message, m_messages) {
-        int messageHeight = message->y() + message->height();
-        if (lowestMessage < messageHeight) {
-            lowestMessage = messageHeight;
+    if (m_pLine) {
+        int lowestMessage = 0;
+        foreach (MessageWidget* message, m_messages) {
+            int messageHeight = message->y() + message->height();
+            if (lowestMessage < messageHeight) {
+                lowestMessage = messageHeight;
+            }
         }
+        m_pLine->setEndOfLine(lowestMessage + sequenceLineMargin);
     }
-    m_pLine->setEndOfLine(lowestMessage + sequenceLineMargin);
 }
 
 /**
@@ -546,14 +639,14 @@ void ObjectWidget::slotMessageMoved()
  * @param y               top of your message
  * @param messageWidget   pointer to your message so it doesn't check against itself
  */
-bool ObjectWidget::messageOverlap(UMLSceneValue y, MessageWidget* messageWidget)
+bool ObjectWidget::messageOverlap(qreal y, MessageWidget* messageWidget)
 {
     foreach (MessageWidget* message, m_messages) {
         if (message == messageWidget) {
             continue;
         }
-        const UMLSceneValue msgY = message->y();
-        const UMLSceneValue msgHeight = msgY + message->height();
+        const qreal msgY = message->y();
+        const qreal msgHeight = msgY + message->height();
         if (y >= msgY && y <= msgHeight) {
             return true;
         }
@@ -571,18 +664,44 @@ SeqLineWidget *ObjectWidget::sequentialLine() const
     return m_pLine;
 }
 
+/**
+ * Overridden from UMLWidget.
+ * Returns the cursor to be shown when resizing the widget.
+ * The cursor shown is KCursor::sizeHorCursor().
+ *
+ * @return The cursor to be shown when resizing the widget.
+ */
+QCursor ObjectWidget::resizeCursor() const
+{
+    return Qt::SizeHorCursor;
+}
+
+/**
+ * Overridden from UMLWidget.
+ * Resizes the width of the object widget.
+ * Object widgets can only be resized horizontally, so height isn't modified.
+ *
+ * @param newW   The new width for the widget.
+ * @param newH   The new height for the widget (isn't used).
+ */
+void ObjectWidget::resizeWidget(qreal newW, qreal newH)
+{
+    Q_UNUSED(newH);
+    setSize(newW, height());
+}
+
 /**
  * Saves to the "objectwidget" XMI element.
  */
 void ObjectWidget::saveToXMI(QDomDocument& qDoc, QDomElement& qElement)
 {
-    QDomElement objectElement = qDoc.createElement( "objectwidget" );
-    UMLWidget::saveToXMI( qDoc, objectElement );
-    objectElement.setAttribute( "drawasactor", m_drawAsActor );
-    objectElement.setAttribute( "multipleinstance", m_multipleInstance );
-    objectElement.setAttribute( "localid", Uml::ID::toString(m_nLocalID) );
-    objectElement.setAttribute( "decon", m_showDestruction );
-    qElement.appendChild( objectElement );
+    QDomElement objectElement = qDoc.createElement("objectwidget");
+    UMLWidget::saveToXMI(qDoc, objectElement);
+    objectElement.setAttribute("drawasactor", m_drawAsActor);
+    objectElement.setAttribute("multipleinstance", m_multipleInstance);
+    objectElement.setAttribute("localid", Uml::ID::toString(m_nLocalID));
+    objectElement.setAttribute("decon", m_showDestruction);
+    qElement.appendChild(objectElement);
 }
 
 /**
@@ -590,12 +709,12 @@ void ObjectWidget::saveToXMI(QDomDocument& qDoc, QDomElement& qElement)
  */
 bool ObjectWidget::loadFromXMI(QDomElement& qElement)
 {
-    if( !UMLWidget::loadFromXMI( qElement ) )
+    if(!UMLWidget::loadFromXMI(qElement))
         return false;
-    QString draw = qElement.attribute( "drawasactor", "0" );
-    QString multi = qElement.attribute( "multipleinstance", "0" );
-    QString localid = qElement.attribute( "localid", "0" );
-    QString decon = qElement.attribute( "decon", "0" );
+    QString draw = qElement.attribute("drawasactor", "0");
+    QString multi = qElement.attribute("multipleinstance", "0");
+    QString localid = qElement.attribute("localid", "0");
+    QString decon = qElement.attribute("decon", "0");
 
     m_drawAsActor = (bool)draw.toInt();
     m_multipleInstance = (bool)multi.toInt();
